diff lisp/vc-sccs.el @ 85141:b16f7408cd3f

Carry through today's big terminology change to a few places where I missed it in the back ends.
author Eric S. Raymond <esr@snark.thyrsus.com>
date Wed, 10 Oct 2007 19:39:23 +0000
parents 8ba0e30716a5
children 315124ffb889 d38543a1c0f9
line wrap: on
line diff
--- a/lisp/vc-sccs.el	Wed Oct 10 19:18:53 2007 +0000
+++ b/lisp/vc-sccs.el	Wed Oct 10 19:39:23 2007 +0000
@@ -148,10 +148,10 @@
 (defun vc-sccs-working-revision (file)
   "SCCS-specific version of `vc-working-revision'."
   (with-temp-buffer
     ;; The workfile version is always the latest version number.
     ;; To find this number, search the entire delta table,
     ;; rather than just the first entry, because the
     ;; first entry might be a deleted ("R") version.
     (vc-insert-file (vc-name file) "^\001e\n\001[^s]")
     (vc-parse-buffer "^\001d D \\([^ ]+\\)" 1)))
 
@@ -230,7 +230,7 @@
 	 (vc-switches 'SCCS 'checkout)))
 
 (defun vc-sccs-checkout (file &optional editable rev)
-  "Retrieve a copy of a saved version of SCCS controlled FILE.
+  "Retrieve a copy of a saved revision of SCCS controlled FILE.
 EDITABLE non-nil means that the file should be writable and
 locked.  REV is the revision to check out."
   (let ((file-buffer (get-file-buffer file))
@@ -258,7 +258,7 @@
 		 switches))))
     (message "Checking out %s...done" file)))
 
-(defun vc-sccs-cancel-version (files)
+(defun vc-sccs-rollback (files)
   "Roll back, undoing the most recent checkins of FILES."
   (if (not files)
       (error "SCCS backend doesn't support directory-level rollback."))
@@ -275,8 +275,8 @@
   "Revert FILE to the version it was based on."
   (vc-do-command nil 0 "unget" (vc-name file))
   (vc-do-command nil 0 "get" (vc-name file))
   ;; Checking out explicit versions is not supported under SCCS, yet.
   ;; We always "revert" to the latest version; therefore
   ;; vc-working-revision is cleared here so that it gets recomputed.
   (vc-file-setprop file 'vc-working-revision nil))
 
@@ -322,7 +322,7 @@
 ;;;
 
 (defun vc-sccs-assign-name (file name)
-  "Assign to FILE's latest version a given NAME."
+  "Assign to FILE's latest revision a given NAME."
   (vc-sccs-add-triple name file (vc-working-revision file)))
 
 
@@ -388,7 +388,7 @@
 
 (defun vc-sccs-parse-locks ()
   "Parse SCCS locks in current buffer.
-The result is a list of the form ((VERSION . USER) (VERSION . USER) ...)."
+The result is a list of the form ((REVISION . USER) (REVISION . USER) ...)."
   (let (master-locks)
     (goto-char (point-min))
     (while (re-search-forward "^\\([0-9.]+\\) [0-9.]+ \\([^ ]+\\) .*\n?"
@@ -409,8 +409,8 @@
     (kill-buffer (current-buffer))))
 
 (defun vc-sccs-lookup-triple (file name)
-  "Return the numeric version corresponding to a named snapshot of FILE.
-If NAME is nil or a version number string it's just passed through."
+  "Return the numeric revision corresponding to a named snapshot of FILE.
+If NAME is nil or a revision number string it's just passed through."
   (if (or (null name)
 	  (let ((firstchar (aref name 0)))
 	    (and (>= firstchar ?0) (<= firstchar ?9))))
@@ -148,10 +148,10 @@
   "SCCS-specific version of `vc-working-revision'."
   (with-temp-buffer
-    ;; The workfile version is always the latest version number.
+    ;; The working revision is always the latest revision number.
     ;; To find this number, search the entire delta table,
     ;; rather than just the first entry, because the
@@ -148,10 +148,10 @@
     ;; To find this number, search the entire delta table,
     ;; rather than just the first entry, because the
-    ;; first entry might be a deleted ("R") version.
+    ;; first entry might be a deleted ("R") revision.
     (vc-insert-file (vc-name file) "^\001e\n\001[^s]")
     (vc-parse-buffer "^\001d D \\([^ ]+\\)" 1)))
@@ -275,8 +275,8 @@
   (vc-do-command nil 0 "unget" (vc-name file))
   (vc-do-command nil 0 "get" (vc-name file))
-  ;; Checking out explicit versions is not supported under SCCS, yet.
-  ;; We always "revert" to the latest version; therefore
+  ;; Checking out explicit revisions is not supported under SCCS, yet.
+  ;; We always "revert" to the latest revision; therefore
   ;; vc-working-revision is cleared here so that it gets recomputed.
   (vc-file-setprop file 'vc-working-revision nil))